==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/so-KE.pl <==
{
  am_pm_abbreviated => [
    "sn.",
    "gn.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-one" => "'usbuuc' W 'ee' MMMM",
    "MMMMW-count-other" => "'usbuuc' W 'ee' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "so-KE",
  date_format_full => "EEEE, MMMM dd, y",
  date_format_long => "dd MMMM y",
  date_format_medium => "dd-MMM-y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Isn",
    "Tal",
    "Arb",
    "Kha",
    "Jim",
    "Sab",
    "Axd",
  ],
  day_format_narrow => [
    "I",
    "T",
    "A",
    "Kh",
    "J",
    "S",
    "A",
  ],
  day_format_wide => [
    "Isniin",
    "Talaado",
    "Arbaco",
    "Khamiis",
    "Jimco",
    "Sabti",
    "Axad",
  ],
  day_stand_alone_abbreviated => [
    "Isn",
    "Tal",
    "Arb",
    "Kha",
    "Jim",
    "Sab",
    "Axd",
  ],
  day_stand_alone_narrow => [
    "I",
    "T",
    "A",
    "Kh",
    "J",
    "S",
    "A",
  ],
  day_stand_alone_wide => [
    "Isniin",
    "Talaado",
    "Arbaco",
    "Khamiis",
    "Jimco",
    "Sabti",
    "Axad",
  ],
  era_abbreviated => [
    "CK",
    "CD",
  ],
  era_narrow => [
    "CK",
    "CD",
  ],
  era_wide => [
    "CK",
    "CD",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A, %B %e, %r %Z %Y",
  glibc_date_format => "%d/%m/%Y",
  glibc_datetime_format => "%A, %B %e, %Y %r %Z",
  glibc_time_12_format => "%X %p",
  glibc_time_format => "%l:%M:%S",
  language => "Somali",
  month_format_abbreviated => [
    "Kob",
    "Lab",
    "Sad",
    "Afr",
    "Sha",
    "Lix",
    "Tod",
    "Sid",
    "Sag",
    "Tob",
    "KIT",
    "LIT",
  ],
  month_format_narrow => [
    "K",
    "L",
    "S",
    "A",
    "S",
    "L",
    "T",
    "S",
    "S",
    "T",
    "K",
    "L",
  ],
  month_format_wide => [
    "Bisha Koobaad",
    "Bisha Labaad",
    "Bisha Saddexaad",
    "Bisha Afraad",
    "Bisha Shanaad",
    "Bisha Lixaad",
    "Bisha Todobaad",
    "Bisha Sideedaad",
    "Bisha Sagaalaad",
    "Bisha Tobnaad",
    "Bisha Kow iyo Tobnaad",
    "Bisha Laba iyo Tobnaad",
  ],
  month_stand_alone_abbreviated => [
    "Kob",
    "Lab",
    "Sad",
    "Afr",
    "Sha",
    "Lix",
    "Tod",
    "Sid",
    "Sag",
    "Tob",
    "KIT",
    "LIT",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Bisha Koobaad",
    "Bisha Labaad",
    "Bisha Saddexaad",
    "Bisha Afraad",
    "Bisha Shanaad",
    "Bisha Lixaad",
    "Bisha Todobaad",
    "Bisha Sideedaad",
    "Bisha Sagaalaad",
    "Bisha Tobnaad",
    "Bisha Kow iyo Tobnaad",
    "Bisha Laba iyo Tobnaad",
  ],
  name => "Somali Kenya",
  native_language => "Soomaali",
  native_name => "Soomaali Kiiniya",
  native_script => undef,
  native_territory => "Kiiniya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Rubaca 1aad",
    "Rubaca 2aad",
    "Rubaca 3aad",
    "Rubaca 4aad",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Rubaca 1aad",
    "Rubaca 2aad",
    "Rubaca 3aad",
    "Rubaca 4aad",
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> DateTime-Locale-1.31.tar.gz: DateTime-Locale-1.31/share/so-KE.pl <==
{
  am_pm_abbreviated => [
    "GH",
    "GD",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-one" => "'toddobaadka' W 'ee' MMMM",
    "MMMMW-count-other" => "'toddobaadka' W 'ee' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'toddobaadka' w 'ee' Y",
    "yw-count-other" => "'toddobaadka' w 'ee' Y",
  },
  code => "so-KE",
  date_format_full => "EEEE, MMMM dd, y",
  date_format_long => "dd MMMM y",
  date_format_medium => "dd-MMM-y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Isn",
    "Tldo",
    "Arbc",
    "Khms",
    "Jmc",
    "Sbti",
    "Axd",
  ],
  day_format_narrow => [
    "I",
    "T",
    "A",
    "Kh",
    "J",
    "S",
    "A",
  ],
  day_format_wide => [
    "Isniin",
    "Talaado",
    "Arbaco",
    "Khamiis",
    "Jimco",
    "Sabti",
    "Axad",
  ],
  day_stand_alone_abbreviated => [
    "Isn",
    "Tldo",
    "Arbc",
    "Khms",
    "Jmc",
    "Sbti",
    "Axd",
  ],
  day_stand_alone_narrow => [
    "I",
    "T",
    "A",
    "Kh",
    "J",
    "S",
    "A",
  ],
  day_stand_alone_wide => [
    "Isniin",
    "Talaado",
    "Arbaco",
    "Khamiis",
    "Jimco",
    "Sabti",
    "Axad",
  ],
  era_abbreviated => [
    "CH",
    "CD",
  ],
  era_narrow => [
    "B",
    "A",
  ],
  era_wide => [
    "Ciise Hortii",
    "Ciise Dabadii",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A, %B %e, %X %Z %Y",
  glibc_date_format => "%d/%m/%Y",
  glibc_datetime_format => "%A, %B %e, %Y %X %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Somali",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "May",
    "Jun",
    "Lul",
    "Ogs",
    "Seb",
    "Okt",
    "Nof",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "L",
    "O",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Bisha Koobaad",
    "Bisha Labaad",
    "Bisha Saddexaad",
    "Bisha Afraad",
    "Bisha Shanaad",
    "Bisha Lixaad",
    "Bisha Todobaad",
    "Bisha Sideedaad",
    "Bisha Sagaalaad",
    "Bisha Tobnaad",
    "Bisha Kow iyo Tobnaad",
    "Bisha Laba iyo Tobnaad",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "May",
    "Jun",
    "Lul",
    "Ogs",
    "Seb",
    "Okt",
    "Nof",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "L",
    "O",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Jannaayo",
    "Febraayo",
    "Maarso",
    "Abriil",
    "May",
    "Juun",
    "Luuliyo",
    "Ogost",
    "Sebtembar",
    "Oktoobar",
    "Nofembar",
    "Desembar",
  ],
  name => "Somali Kenya",
  native_language => "Soomaali",
  native_name => "Soomaali Kenya",
  native_script => undef,
  native_territory => "Kenya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Rubaca 1aad",
    "Rubaca 2aad",
    "Rubaca 3aad",
    "Rubaca 4aad",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Rubaca 1aad",
    "Rubaca 2aad",
    "Rubaca 3aad",
    "Rubaca 4aad",
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 38,
}
